@@ -40,7 +40,7 @@ import qualified Data.List as List
 import Control.Applicative (Applicative, pure, )
 import Data.Monoid (Monoid, mempty, mappend, )
 
-import Test.QuickCheck (Arbitrary, arbitrary, )
+import Test.QuickCheck (Arbitrary(arbitrary, shrink))
 
 import Data.Tuple.HT (mapFst, mapSnd, mapPair, )
 import Data.Maybe.HT (toMaybe, )
@@ -83,6 +83,7 @@ instance (Show a, Show b) => Show (T a b) where
 instance (Arbitrary a, Arbitrary b) =>
              Arbitrary (T a b) where
    arbitrary = Monad.liftM2 Cons arbitrary arbitrary
+   shrink (Cons x xs) = fmap (uncurry Cons) $ shrink (x,xs)
 
 
 
