@@ -18,7 +18,7 @@ import qualified Control.Applicative as App
 import Control.Applicative (Applicative, )
 import Data.Monoid (Monoid, mempty, mappend, mconcat, )
 
-import Test.QuickCheck (Arbitrary(arbitrary))
+import Test.QuickCheck (Arbitrary(arbitrary, shrink))
 
 import Prelude hiding (concat, cycle)
 
@@ -30,6 +30,7 @@ newtype T time body = Cons {decons :: Disp.T time body}
 instance (Arbitrary time, Arbitrary body) =>
              Arbitrary (T time body) where
    arbitrary = Monad.liftM Cons arbitrary
+   shrink = liftM shrink
 
 instance (Num time, Ord time) => Monoid (T time body) where
    mempty = Cons Disp.empty
