@@ -31,7 +31,7 @@ import qualified Control.Applicative as App
 import Control.Applicative (Applicative, )
 import Data.Monoid (Monoid, mempty, mappend, mconcat, )
 
-import Test.QuickCheck (Arbitrary(arbitrary))
+import Test.QuickCheck (Arbitrary(arbitrary, shrink))
 
 import Prelude hiding (foldr, )
 
@@ -46,6 +46,7 @@ instance (Show time, Show body) => Show (T time body) where
 instance (Arbitrary time, Arbitrary body) =>
              Arbitrary (T time body) where
    arbitrary = Monad.liftM Cons arbitrary
+   shrink = liftM shrink
 
 
 instance (NonNeg.C time) => Monoid (T time body) where
