@@ -3,7 +3,7 @@ module Test.Utility where
 
 import qualified Numeric.NonNegative.Wrapper as NonNeg
 
-import Test.QuickCheck (Arbitrary(arbitrary))
+import Test.QuickCheck (Arbitrary(arbitrary, shrink))
 
 import qualified Data.Char as Char
 import System.Random (Random, )
@@ -18,6 +18,7 @@ instance Show ArbChar where
 
 instance Arbitrary ArbChar where
    arbitrary = liftM (ArbChar . Char.chr . (32+) . flip mod 96) arbitrary
+   shrink (ArbChar c) = map ArbChar $ shrink c
 
 toLower :: ArbChar -> ArbChar
 toLower (ArbChar c) = ArbChar (Char.toLower c)
